@@ -4,13 +4,14 @@ import sys
 
 import click
 
-from cleantoots.commands import clean as clean_commands, config as config_commands
+from cleantoots.commands import clean as clean_commands
+from cleantoots.commands import config as config_commands
 from cleantoots.utils import CleanTootsConfig
 
 DEFAULT_CONFIG_DIR = click.get_app_dir("cleantoots")
 DEFAULT_CONFIG_FILENAME = "config.ini"
 
-CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
+CONTEXT_SETTINGS = {"help_option_names": ["-h", "--help"]}
 
 
 @click.group(context_settings=CONTEXT_SETTINGS)
